#!/bin/bash
#
# serge
# requires you to ssh-keygen and put id_rsa.pub into
# .ssh/authorized_keys

if [ $# -lt 2 ]; then
	echo "Usage: $0 jobname program"
	exit 1
fi

jobname=$1
program=$2

vardir=/var/lib/crdemo/$jobname
if [ -d $vardir ]; then
	echo "$vardir exists.  Please terminate existing jobs and rmdir"
	exit 1
fi
mkdir -p $vardir
cp $program $vardir/

# create addresses
# XXX TODO make this play nicely with multiple jobs!
ip link add type veth
d0=veth0
d1=veth1
a0=10.50.1.1
a1=10.50.1.2

ifconfig $d0 $a0 up
ifconfig $d1 $a1 up

echo $d0 > $vardir/addr
echo $a0 >> $vardir/addr
echo $d1 >> $vardir/addr
echo $a1 >> $vardir/addr

CONTAINERINIT=/usr/bin/jobinit.sh

nohup nsexec -tncmpiu $CONTAINERINIT $jobname &
echo "Waiting for $vardir/container_waiting to be created..."
while [ ! -f $vardir/container_waiting ]; do
	echo -n '.'
	sleep 1
done
pid=`head -1 /cgroup/$jobname/tasks`
ip link set $d1 netns $pid

touch $vardir/devready

echo "Waiting for $vardir/container_ready to be created..."
while [ ! -f $vardir/container_ready ]; do 
	echo -n '.'
	sleep 1
done

route add -host $a1 gateway $a0

echo "$vardir/container_ready was created.  Ssh'ing into container to start $program"
ssh root@$a1 screen -A -d -m -S $jobname $vardir/$program
ps -ef | grep -v grep | grep $program > /dev/null 2>&1
ret=$?
echo "Waiting for $program to start..."
while [ $ret -ne 0 ]; do
	echo -n '.'
	ps -ef | grep -v grep | grep $program > /dev/null 2>&1
	ret=$?
done
echo "Program $program started.  You can ssh to $a1 and 'screen -r'."
#echo "ssh to $a1 and screen -r, make any changes you like, logout,"
#echo "then use /usr/bin/checkpoint.sh, kill, use /bin/restart.sh"
#echo "and look for successful restart"
